import { AfterViewInit, OnDestroy, ElementRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
export interface CanvasModel {
    width: number;
    height: number;
    vectors: string[][];
    imgUrl?: string;
}
export declare const defaultCanvasModel: CanvasModel;
export declare type onCanvasChange = ($event?: CanvasModel) => any;
export declare class CanvasInputComponent implements AfterViewInit, OnDestroy, ControlValueAccessor {
    color: string;
    size: number;
    opacity: number;
    offsetTop: number;
    offsetLeft: number;
    paperRef: ElementRef<HTMLCanvasElement>;
    paper: HTMLCanvasElement;
    ctx: CanvasRenderingContext2D;
    private paint;
    width: number;
    height: number;
    vectors: any[];
    img: HTMLImageElement;
    imgLoaded: boolean;
    imgUrl: string;
    disabled: boolean;
    viewInitiated: boolean;
    private onChangeListeners;
    private onBlurListeners;
    constructor();
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Writes a new value to the element.
     *
     * This method is called by the forms API to write to the view when programmatic
     * changes from model to view are requested.
     */
    writeValue(value: CanvasModel): any;
    loadImage(): any;
    /**
     * Registers a callback function that is called when the control's value
     * changes in the UI.
     *
     * This method is called by the forms API on initialization to update the form
     * model when values propagate from the view to the model.
     */
    registerOnChange(fn: onCanvasChange): void;
    /**
     * Registers a callback function is called by the forms API on initialization
     * to update the form model on blur.
     */
    registerOnTouched(fn: onCanvasChange): void;
    /**
     * Function that is called by the forms API when the control status changes to
     * or from 'DISABLED'. Depending on the status, it enables or disables the
     * appropriate DOM element.
     */
    setDisabledState?(isDisabled: boolean): void;
    onMouseDown(e: MouseEvent): any;
    onTouchStart(e: TouchEvent): any;
    onMouseMove(e: MouseEvent): any;
    onTouchMove(e: TouchEvent): any;
    disablePaint(e: MouseEvent | TouchEvent): void;
    addPoint(x: number, y: number, drag?: boolean): void;
    private _reDraw;
}
